binman: Handle reading data for end-at-4gb sections

Some x86 sections have special offsets which currently result in empty
data being returned from the 'extract' command. Fix this by taking account
of the skip-at-start property.

Add a little more debugging while we are here.

Signed-off-by: Simon Glass <sjg@chromium.org>
Acked-by: Bin Meng <bmeng.cn@gmail.com>
diff --git a/tools/binman/entry.py b/tools/binman/entry.py
index f2f1b96..fe8e1dd 100644
--- a/tools/binman/entry.py
+++ b/tools/binman/entry.py
@@ -714,17 +714,19 @@
         """
         # Use True here so that we get an uncompressed section to work from,
         # although compressed sections are currently not supported
+        tout.Debug("ReadChildData section '%s', entry '%s'" %
+                   (self.section.GetPath(), self.GetPath()))
         data = self.section.ReadChildData(self, decomp)
         return data
 
     def ReadChildData(self, child, decomp=True):
         """Read the data for a particular child
 
         This reads data from the parent and extracts the piece that relates to
         the given child.
 
         Args:
             child: Child to read (must be valid)
             decomp: True to decompress any compressed data before returning it;
                 False to return the raw, uncompressed data
@@ -714,17 +714,19 @@
 
     def ReadChildData(self, child, decomp=True):
-        """Read the data for a particular child
+        """Read the data for a particular child entry
 
         This reads data from the parent and extracts the piece that relates to
@@ -714,17 +714,19 @@
 
         Args:
-            child: Child to read (must be valid)
+            child: Child entry to read data for (must be valid)
             decomp: True to decompress any compressed data before returning it;
                 False to return the raw, uncompressed data